@@ -17,7 +17,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0R (Compaq Armada M700)
  *
-$Id: battstat.h,v 1.22 2004/05/17 02:06:25 davyd Exp $
+$Id: battstat.h,v 1.25 2004/10/26 14:17:56 davyd Exp $
  */
 
 #define DEBUG 0
@@ -32,6 +32,12 @@ $Id: battstat.h,v 1.22 2004/05/17 02:06:25 davyd Exp $
 
 #define PROGLEN 33.0
 
+enum {
+	APPLET_SHOW_NONE,
+	APPLET_SHOW_PERCENT,
+	APPLET_SHOW_TIME
+};
+
 /*
  * Not used yet... 
  */
@@ -52,7 +58,9 @@ typedef struct _ProgressData {
   GtkWidget *radio_orient_horizont;
   GtkWidget *radio_lay_batt_on;
   GtkWidget *radio_lay_status_on;
-  GtkWidget *radio_lay_percent_on;
+  GtkWidget *radio_text_1;
+  GtkWidget *radio_text_2;
+  GtkWidget *check_text;
   GdkPixmap *pixbuffer;
   GdkBitmap *pixmask;
   GdkPixmap *pixbuffery;
@@ -88,7 +96,7 @@ typedef struct _ProgressData {
   gboolean horizont;
   gboolean showstatus;
   gboolean showbattery;
-  gboolean showpercent;
+  int showtext;
 
   GtkWidget *suspend_entry;
   char *suspend_cmd;
@@ -98,23 +106,11 @@ typedef struct _ProgressData {
   guint yellow_val;
   int panelsize;
   PanelAppletOrient orienttype;
-  GtkObject *ered_adj;
-  GtkObject *eorange_adj;
-  GtkObject *eyellow_adj;
   int pixtimer;
   int acpiwatch;
 
   GtkWidget *lowbatt_toggle;
   GtkWidget *full_toggle;
-  GtkWidget *testpercent;
-  GdkPixmap *testpixmap;
-  GdkBitmap *testmask;
-  GdkPixmap *testpixbuffer;
-  GdkBitmap *testpixmask;
-  GdkGC *testpixgc;
-  GtkWidget *testpixmapwid;
-  GtkObject *testadj;
-  GtkWidget *beep_toggle;
   GtkWidget *lowbattnotificationdialog;
 
   /* last_* for the benefit of the timeout functions */
@@ -150,7 +146,7 @@ void help_cb (BonoboUIComponent *, ProgressData *, const char *);
 void suspend_cb (BonoboUIComponent *, ProgressData *, const char *);
 void destroy_about (GtkWidget *, gpointer);
 void about_cb (BonoboUIComponent *, ProgressData *, const char *);
-void change_size(PanelApplet *, gint, gpointer);
+void size_allocate(PanelApplet *, GtkAllocation *, gpointer);
 void change_background(PanelApplet *a, PanelAppletBackgroundType type, 
 		GdkColor *color, GdkPixmap *pixmap, ProgressData *battstat);	
 gint create_layout(ProgressData *battstat);
