@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.85 2004/07/07 00:52:12 gowen Exp $ */
+/* $Id: gweather-applet.c,v 1.88 2004/10/22 14:10:36 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -21,7 +21,6 @@
 #include <gnome.h>
 #include <panel-applet.h>
 #include <libgnomeui/gnome-window-icon.h>
-#include <egg-screen-help.h>
 
 #include "weather.h"
 #include "gweather.h"
@@ -167,7 +166,11 @@ static gboolean clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data
         return FALSE;
 
     if (ev->type == GDK_BUTTON_PRESS) {
-	gweather_dialog_open(gw_applet);
+	if (!gw_applet->gweather_dialog)
+		gweather_dialog_open (gw_applet);
+	else
+		gweather_dialog_close (gw_applet);
+	
 	return TRUE;
     }
     
@@ -184,7 +187,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GWeatherApplet *gw_applet)
 			return TRUE;
 		}
 		break;
-	case GDK_f:
+	case GDK_d:
 		if (event->state == GDK_CONTROL_MASK) {
 			gweather_dialog_open (gw_applet);
 			return TRUE;
@@ -221,7 +224,7 @@ static void help_cb (BonoboUIComponent *uic,
 {
     GError *error = NULL;
 
-    egg_help_display_on_screen (
+    gnome_help_display_on_screen (
 		"gweather", NULL,
 		gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)),
 		&error);
@@ -240,7 +243,7 @@ static void pref_cb (BonoboUIComponent *uic,
     gweather_pref_run (gw_applet);
 }
 
-static void forecast_cb (BonoboUIComponent *uic,
+static void details_cb (BonoboUIComponent *uic,
 		         GWeatherApplet    *gw_applet,
 			 const gchar       *verbname)
 {
@@ -256,7 +259,7 @@ static void update_cb (BonoboUIComponent *uic,
 
 
 static const BonoboUIVerb weather_applet_menu_verbs [] = {
-	BONOBO_UI_UNSAFE_VERB ("Forecast", forecast_cb),
+	BONOBO_UI_UNSAFE_VERB ("Details", details_cb),
 	BONOBO_UI_UNSAFE_VERB ("Update", update_cb),
         BONOBO_UI_UNSAFE_VERB ("Props", pref_cb),
         BONOBO_UI_UNSAFE_VERB ("Help", help_cb), 
@@ -347,7 +350,7 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
 		       G_CALLBACK(change_background_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "destroy", 
                        G_CALLBACK (applet_destroy), gw_applet);
-    gtk_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
+    g_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
                        GTK_SIGNAL_FUNC(clicked_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "key_press_event",           
 			G_CALLBACK(key_press_cb), gw_applet);                    
