@@ -33,7 +33,6 @@
 #include <libgnomeui/gnome-color-picker.h>
 #include <glade/glade-xml.h>
 #include <gconf/gconf-client.h>
-#include <egg-screen-help.h>
 
 #include "mini-commander_applet.h"
 #include "command_line.h"
@@ -88,7 +87,7 @@ mc_key_writable (MCData *mc, const char *key)
 }
 
 
-/* GConf notfication handlers
+/* GConf notification handlers
  */
 static void
 show_default_theme_changed (GConfClient  *client,
@@ -104,34 +103,6 @@ show_default_theme_changed (GConfClient  *client,
     mc_applet_draw (mc); /* FIXME: we shouldn't have to redraw the whole applet */
 }
 
-static void
-show_handle_changed (GConfClient  *client,
-		     guint         cnxn_id,
-		     GConfEntry   *entry,
-		     MCData       *mc)
-{
-    if (!entry->value || entry->value->type != GCONF_VALUE_BOOL)
-	return;
-
-    mc->preferences.show_handle = gconf_value_get_bool (entry->value);
-
-    mc_applet_draw (mc); /* FIXME: we shouldn't have to redraw the whole applet */
-}
-
-static void
-show_frame_changed (GConfClient  *client,
-		    guint         cnxn_id,
-		    GConfEntry   *entry,
-		    MCData       *mc)
-{
-    if (!entry->value || entry->value->type != GCONF_VALUE_BOOL)
-	return;
-
-    mc->preferences.show_frame = gconf_value_get_bool (entry->value);
-
-    mc_applet_draw (mc); /* FIXME: we shouldn't have to redraw the whole applet */
-}
-
 static void
 auto_complete_history_changed (GConfClient  *client,
 			       guint         cnxn_id,
@@ -294,6 +265,7 @@ save_macros_to_gconf (MCData *mc)
     GConfValue    *commands;
     GSList        *pattern_list = NULL;
     GSList        *command_list = NULL;
+    GConfClient   *client;
 
     dialog = &mc->prefs_dialog;
 
@@ -327,9 +299,12 @@ save_macros_to_gconf (MCData *mc)
 
     gconf_value_set_list_nocopy (patterns, pattern_list); pattern_list = NULL;
     gconf_value_set_list_nocopy (commands, command_list); command_list = NULL;
-
-    panel_applet_gconf_set_value (mc->applet, "macro_patterns", patterns, NULL);
-    panel_applet_gconf_set_value (mc->applet, "macro_commands", commands, NULL);
+    
+    client = gconf_client_get_default ();
+    gconf_client_set (client, "/apps/mini-commander/macro_patterns",
+		    patterns, NULL);
+    gconf_client_set (client, "/apps/mini-commander/macro_commands",
+		    commands, NULL);
 
     gconf_value_free (patterns);
     gconf_value_free (commands);
@@ -377,7 +352,7 @@ show_help_section (GtkWindow *dialog, gchar *section)
      						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 	}
 
-	egg_help_display_desktop_on_screen (
+	gnome_help_display_desktop_on_screen (
 			applet_program, "command-line", "command-line", section,
 			gtk_widget_get_screen (GTK_WIDGET (dialog)),
 			&error);
@@ -620,32 +595,6 @@ background_color_set (GtkWidget *color_picker,
     panel_applet_gconf_set_int (mc->applet, "cmd_line_color_bg_b", (int) blue, NULL);
 }
 
-static void
-show_handle_toggled (GtkToggleButton *toggle,
-                     MCData          *mc)
-{
-    gboolean show_handle;
-    
-    show_handle = gtk_toggle_button_get_active (toggle);
-    if (show_handle == mc->preferences.show_handle) 
-        return;
-        
-    panel_applet_gconf_set_bool (mc->applet, "show_handle", show_handle, NULL);
-}
-
-static void
-show_frame_toggled (GtkToggleButton *toggle,
-		    MCData          *mc)
-{
-    gboolean show_frame;
-    
-    show_frame = gtk_toggle_button_get_active (toggle);
-    if (show_frame == mc->preferences.show_frame) 
-        return;
-        
-    panel_applet_gconf_set_bool (mc->applet, "show_frame", show_frame, NULL);
-}
-
 static void
 auto_complete_history_toggled (GtkToggleButton *toggle,
 			       MCData          *mc)
@@ -728,6 +677,7 @@ mc_preferences_setup_dialog (GladeXML *xml,
 {
     MCPrefsDialog   *dialog;
     GtkCellRenderer *renderer;
+    GConfClient     *client;
 
     dialog = &mc->prefs_dialog;
 
@@ -737,8 +687,6 @@ mc_preferences_setup_dialog (GladeXML *xml,
     gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog), GTK_RESPONSE_CLOSE);
     gtk_window_set_default_size (GTK_WINDOW (dialog->dialog), 400, -1);
 
-    dialog->show_handle_toggle           = glade_xml_get_widget (xml, "show_handle_toggle");
-    dialog->show_frame_toggle            = glade_xml_get_widget (xml, "show_frame_toggle");
     dialog->auto_complete_history_toggle = glade_xml_get_widget (xml, "auto_complete_history_toggle");
     dialog->size_spinner                 = glade_xml_get_widget (xml, "size_spinner");
     dialog->use_default_theme_toggle     = glade_xml_get_widget (xml, "default_theme_toggle");
@@ -748,22 +696,6 @@ mc_preferences_setup_dialog (GladeXML *xml,
     dialog->delete_button                = glade_xml_get_widget (xml, "delete_button");
     dialog->add_button                   = glade_xml_get_widget (xml, "add_button");
 
-    /* Show handle */
-    g_signal_connect (dialog->show_handle_toggle, "toggled",
-		      G_CALLBACK (show_handle_toggled), mc);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->show_handle_toggle),
-				  mc->preferences.show_handle);
-    if ( ! mc_key_writable (mc, "show_handle"))
-	    hard_set_sensitive (dialog->show_handle_toggle, FALSE);
-
-    /* Show frame */
-    g_signal_connect (dialog->show_frame_toggle, "toggled",
-		      G_CALLBACK (show_frame_toggled), mc);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->show_frame_toggle),
-				  mc->preferences.show_frame);
-    if ( ! mc_key_writable (mc, "show_frame"))
-	    hard_set_sensitive (dialog->show_frame_toggle, FALSE);
-
     /* History based autocompletion */
     g_signal_connect (dialog->auto_complete_history_toggle, "toggled",
 		      G_CALLBACK (auto_complete_history_toggled), mc);
@@ -829,8 +761,11 @@ mc_preferences_setup_dialog (GladeXML *xml,
     g_signal_connect (dialog->delete_button, "clicked", G_CALLBACK (macro_delete), mc);
     g_signal_connect (dialog->add_button, "clicked", G_CALLBACK (macro_add), mc);
 
-    if ( ! mc_key_writable (mc, "macro_patterns") ||
-	 ! mc_key_writable (mc, "macro_commands")) {
+    client = gconf_client_get_default ();
+    if ( ! gconf_client_key_is_writable (client,
+		 "/apps/mini-commander/macro_patterns", NULL) ||
+	 ! gconf_client_key_is_writable (client,
+		 "/apps/mini-commander/macro_commands", NULL)) {
 	    hard_set_sensitive (dialog->add_button, FALSE);
 	    hard_set_sensitive (dialog->delete_button, FALSE);
 	    hard_set_sensitive (dialog->macros_tree, FALSE);
@@ -847,7 +782,7 @@ mc_preferences_setup_dialog (GladeXML *xml,
 
     gtk_tree_view_insert_column_with_attributes (
 			GTK_TREE_VIEW (dialog->macros_tree), -1,
-			"Pattern", renderer,
+			_("Pattern"), renderer,
 			"text", COLUMN_PATTERN,
 			NULL);
 
@@ -857,7 +792,7 @@ mc_preferences_setup_dialog (GladeXML *xml,
 
     gtk_tree_view_insert_column_with_attributes (
 			GTK_TREE_VIEW (dialog->macros_tree), -1,
-			"Command", renderer,
+			_("Command"), renderer,
 			"text", COLUMN_COMMAND,
 			NULL);
 
@@ -930,9 +865,13 @@ mc_load_macros (MCData *mc)
     GConfValue *macro_patterns;
     GConfValue *macro_commands;
     GSList     *macros_list = NULL;
-
-    macro_patterns = panel_applet_gconf_get_value (mc->applet, "macro_patterns", NULL);
-    macro_commands = panel_applet_gconf_get_value (mc->applet, "macro_commands", NULL);
+    GConfClient *client;
+    
+    client = gconf_client_get_default ();
+    macro_patterns = gconf_client_get (client,
+		    "/apps/mini-commander/macro_patterns", NULL);
+    macro_commands = gconf_client_get (client,
+		    "/apps/mini-commander/macro_commands", NULL);
     
     if (macro_patterns && macro_commands) {
     	GSList *patterns;
@@ -992,22 +931,6 @@ mc_setup_listeners (MCData *mc)
                                 NULL, NULL);
     g_free (key);
 
-    key = panel_applet_gconf_get_full_key (PANEL_APPLET (mc->applet), "show_handle");
-    mc->listeners [i++] = gconf_client_notify_add (
-				client, key,
-				(GConfClientNotifyFunc) show_handle_changed,
-                                mc,
-                                NULL, NULL);
-    g_free (key);
-
-    key = panel_applet_gconf_get_full_key (PANEL_APPLET (mc->applet), "show_frame");
-    mc->listeners [i++] = gconf_client_notify_add (
-				client, key,
-				(GConfClientNotifyFunc) show_frame_changed,
-                                mc,
-                                NULL, NULL);
-    g_free (key);
-
     key = panel_applet_gconf_get_full_key (PANEL_APPLET (mc->applet), "autocomplete_history");
     mc->listeners [i++] = gconf_client_notify_add (
 				client, key,
@@ -1082,21 +1005,17 @@ mc_setup_listeners (MCData *mc)
                                 NULL, NULL);
     g_free (key);
 
-    key = panel_applet_gconf_get_full_key (PANEL_APPLET (mc->applet), "macro_patterns");
     mc->listeners [i++] = gconf_client_notify_add (
-				client, key,
+				client, "/apps/mini-commander/macro_patterns",
 				(GConfClientNotifyFunc) macros_changed,
                                 mc,
                                 NULL, NULL);
-    g_free (key);
 
-    key = panel_applet_gconf_get_full_key (PANEL_APPLET (mc->applet), "macro_commands");
     mc->listeners [i++] = gconf_client_notify_add (
-				client, key,
+				client, "/apps/mini-commander/macro_commands",
 				(GConfClientNotifyFunc) macros_changed,
                                 mc,
                                 NULL, NULL);
-    g_free (key);
 
     g_assert (i == MC_NUM_LISTENERS);
 
@@ -1120,22 +1039,6 @@ mc_load_preferences (MCData *mc)
 	mc->preferences.show_default_theme = MC_DEFAULT_SHOW_DEFAULT_THEME;
     }
 
-    mc->preferences.show_handle =
-		panel_applet_gconf_get_bool (mc->applet, "show_handle", &error);
-    if (error) {
-	g_error_free (error);
-	error = NULL;
-	mc->preferences.show_handle = MC_DEFAULT_SHOW_HANDLE;
-    }
-
-    mc->preferences.show_frame =
-		panel_applet_gconf_get_bool (mc->applet, "show_frame", &error);
-    if (error) {
-	g_error_free (error);
-	error = NULL;
-	mc->preferences.show_frame = MC_DEFAULT_SHOW_FRAME;
-    }
-
     mc->preferences.auto_complete_history =
 		panel_applet_gconf_get_bool (mc->applet, "autocomplete_history", &error);
     if (error) {
