@@ -333,12 +333,12 @@ void stickynote_set_locked(StickyNote *note, gboolean locked)
 	if (locked) {
 		gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "lock_img")),
 					 STICKYNOTES_STOCK_LOCKED, size);
-		gtk_tooltips_set_tip(stickynotes->tooltips, note->w_lock, _("Locked note"), NULL);
+		gtk_tooltips_set_tip(stickynotes->tooltips, note->w_lock, _("This note is locked."), NULL);
 	}
 	else {
 		gtk_image_set_from_stock(GTK_IMAGE(glade_xml_get_widget(note->window, "lock_img")),
 					 STICKYNOTES_STOCK_UNLOCKED, size);
-		gtk_tooltips_set_tip(stickynotes->tooltips, note->w_lock, _("Unlocked note"), NULL);
+		gtk_tooltips_set_tip(stickynotes->tooltips, note->w_lock, _("This note is unlocked."), NULL);
 	}
 
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(glade_xml_get_widget(note->menu, "popup_toggle_lock")), locked);
@@ -356,6 +356,10 @@ void stickynote_set_visible(StickyNote *note, gboolean visible)
 		gtk_window_present(GTK_WINDOW(note->w_window));
 		if (note->x != -1 || note->y != -1)
 			gtk_window_move(GTK_WINDOW(note->w_window), note->x, note->y);
+		/* Put the note on all workspaces if necessary. */
+		if (gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/sticky", NULL))
+			gtk_window_stick(GTK_WINDOW(note->w_window));
+
 	}
 	else {
 		/* Hide sticky note */
